@@ -5,7 +5,7 @@
 ** in the input file. */
 #include "first.h"
 #include <stdio.h>
-#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 5 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 
 #include "first.h"
 #include "base.h"
@@ -710,42 +710,42 @@ static void yy_destructor(YYCODETYPE yymajor, YYMINORTYPE *yypminor){
     case 24:
     case 25:
     case 26:
-#line 325 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 325 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { buffer_free((yypminor->yy0)); }
 #line 715 "./configparser.c"
       break;
     case 36:
-#line 316 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 316 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { if ((yypminor->yy91)) (yypminor->yy91)->fn->free((yypminor->yy91)); }
 #line 720 "./configparser.c"
       break;
     case 37:
-#line 317 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 317 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { if ((yypminor->yy91)) (yypminor->yy91)->fn->free((yypminor->yy91)); }
 #line 725 "./configparser.c"
       break;
     case 38:
-#line 318 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 318 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { if ((yypminor->yy91)) (yypminor->yy91)->fn->free((yypminor->yy91)); }
 #line 730 "./configparser.c"
       break;
     case 41:
-#line 319 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 319 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { array_free((yypminor->yy42)); }
 #line 735 "./configparser.c"
       break;
     case 42:
-#line 320 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 320 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { array_free((yypminor->yy42)); }
 #line 740 "./configparser.c"
       break;
     case 43:
-#line 321 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 321 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { buffer_free((yypminor->yy29)); }
 #line 745 "./configparser.c"
       break;
     case 44:
-#line 322 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 322 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { buffer_free((yypminor->yy29)); }
 #line 750 "./configparser.c"
       break;
@@ -1024,7 +1024,7 @@ static void yy_reduce(
         /* No destructor defined for global */
         break;
       case 5:
-#line 298 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 298 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 { yymsp[-1].minor.yy18 = NULL; }
 #line 1029 "./configparser.c"
   yy_destructor(1,&yymsp[0].minor);
@@ -1039,7 +1039,7 @@ static void yy_reduce(
   yy_destructor(1,&yymsp[0].minor);
         break;
       case 9:
-#line 327 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 327 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     buffer_copy_buffer(&yymsp[0].minor.yy91->key, yymsp[-2].minor.yy29);
@@ -1067,7 +1067,7 @@ static void yy_reduce(
   yy_destructor(2,&yymsp[-1].minor);
         break;
       case 10:
-#line 351 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 351 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     if (strncmp(yymsp[-2].minor.yy29->ptr, "env.", sizeof("env.") - 1) == 0) {
@@ -1090,7 +1090,7 @@ static void yy_reduce(
   yy_destructor(3,&yymsp[-1].minor);
         break;
       case 11:
-#line 370 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 370 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     array *vars = ctx->current->value;
@@ -1125,10 +1125,10 @@ static void yy_reduce(
   yy_destructor(4,&yymsp[-1].minor);
         break;
       case 12:
-#line 401 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 401 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (strchr(yymsp[0].minor.yy0->ptr, '.') == NULL) {
-    yygotominor.yy29 = buffer_init_string("var.");
+    buffer_copy_string((yygotominor.yy29 = buffer_init()), "var.");
     buffer_append_string_buffer(yygotominor.yy29, yymsp[0].minor.yy0);
   } else {
     yygotominor.yy29 = yymsp[0].minor.yy0;
@@ -1140,7 +1140,7 @@ static void yy_reduce(
 #line 1140 "./configparser.c"
         break;
       case 13:
-#line 413 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 413 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = NULL;
   if (ctx->ok) {
@@ -1159,7 +1159,7 @@ static void yy_reduce(
   yy_destructor(6,&yymsp[-1].minor);
         break;
       case 14:
-#line 428 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 428 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = yymsp[0].minor.yy91;
   yymsp[0].minor.yy91 = NULL;
@@ -1167,7 +1167,7 @@ static void yy_reduce(
 #line 1167 "./configparser.c"
         break;
       case 15:
-#line 433 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 433 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = NULL;
   if (ctx->ok) {
@@ -1195,7 +1195,7 @@ static void yy_reduce(
 #line 1195 "./configparser.c"
         break;
       case 16:
-#line 458 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 458 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = (data_unset *)array_data_string_init();
   /* assumes array_data_string_init() result does not need swap, buffer_free()*/
@@ -1206,7 +1206,7 @@ static void yy_reduce(
 #line 1206 "./configparser.c"
         break;
       case 17:
-#line 466 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 466 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   char *endptr;
   yygotominor.yy91 = (data_unset *)array_data_integer_init();
@@ -1224,7 +1224,7 @@ static void yy_reduce(
 #line 1224 "./configparser.c"
         break;
       case 18:
-#line 480 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 480 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = (data_unset *)array_data_array_init();
   /* assumes array_data_array_init() result does not need swap, array_free() */
@@ -1235,7 +1235,7 @@ static void yy_reduce(
 #line 1235 "./configparser.c"
         break;
       case 19:
-#line 487 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 487 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy42 = array_init(8);
 }
@@ -1244,7 +1244,7 @@ static void yy_reduce(
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 20:
-#line 490 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 490 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy42 = yymsp[-1].minor.yy42;
   yymsp[-1].minor.yy42 = NULL;
@@ -1254,7 +1254,7 @@ static void yy_reduce(
   yy_destructor(10,&yymsp[0].minor);
         break;
       case 21:
-#line 495 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 495 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy42 = NULL;
   if (ctx->ok) {
@@ -1280,7 +1280,7 @@ static void yy_reduce(
   yy_destructor(11,&yymsp[-1].minor);
         break;
       case 22:
-#line 517 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 517 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy42 = yymsp[-1].minor.yy42;
   yymsp[-1].minor.yy42 = NULL;
@@ -1289,7 +1289,7 @@ static void yy_reduce(
   yy_destructor(11,&yymsp[0].minor);
         break;
       case 23:
-#line 522 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 522 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy42 = NULL;
   if (ctx->ok) {
@@ -1303,7 +1303,7 @@ static void yy_reduce(
 #line 1303 "./configparser.c"
         break;
       case 24:
-#line 533 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 533 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = yymsp[0].minor.yy91;
   yymsp[0].minor.yy91 = NULL;
@@ -1311,7 +1311,7 @@ static void yy_reduce(
 #line 1311 "./configparser.c"
         break;
       case 25:
-#line 537 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 537 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy91 = NULL;
   if (ctx->ok) {
@@ -1334,7 +1334,7 @@ static void yy_reduce(
       case 27:
         break;
       case 28:
-#line 554 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 554 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   data_config *dc;
   dc = configparser_get_data_config(ctx->srv->config_context, CONST_STR_LEN("global"));
@@ -1345,7 +1345,7 @@ static void yy_reduce(
   yy_destructor(13,&yymsp[0].minor);
         break;
       case 29:
-#line 561 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 561 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   force_assert(ctx->current);
   configparser_pop(ctx);
@@ -1358,7 +1358,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 30:
-#line 567 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 567 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1382,7 +1382,7 @@ static void yy_reduce(
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 31:
-#line 586 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 586 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1449,7 +1449,7 @@ static void yy_reduce(
   yy_destructor(16,&yymsp[-1].minor);
         break;
       case 32:
-#line 648 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 648 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy18 = yymsp[0].minor.yy18;
   yymsp[0].minor.yy18 = NULL;
@@ -1457,7 +1457,7 @@ static void yy_reduce(
 #line 1457 "./configparser.c"
         break;
       case 33:
-#line 653 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 653 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1478,7 +1478,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 34:
-#line 667 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 667 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy18 = NULL;
   if (ctx->ok) {
@@ -1499,7 +1499,7 @@ static void yy_reduce(
   yy_destructor(15,&yymsp[0].minor);
         break;
       case 35:
-#line 681 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 681 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
 
   if (ctx->ok && yymsp[0].minor.yy91->type != TYPE_STRING) {
@@ -1524,7 +1524,7 @@ static void yy_reduce(
   yy_destructor(20,&yymsp[-2].minor);
         break;
       case 36:
-#line 700 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 700 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     configparser_parse_else_condition(ctx);
@@ -1533,7 +1533,7 @@ static void yy_reduce(
 #line 1533 "./configparser.c"
         break;
       case 37:
-#line 706 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 706 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy53 = CONFIG_COND_EQ;
 }
@@ -1541,7 +1541,7 @@ static void yy_reduce(
   yy_destructor(21,&yymsp[0].minor);
         break;
       case 38:
-#line 709 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 709 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy53 = CONFIG_COND_MATCH;
 }
@@ -1549,7 +1549,7 @@ static void yy_reduce(
   yy_destructor(22,&yymsp[0].minor);
         break;
       case 39:
-#line 712 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 712 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy53 = CONFIG_COND_NE;
 }
@@ -1557,7 +1557,7 @@ static void yy_reduce(
   yy_destructor(23,&yymsp[0].minor);
         break;
       case 40:
-#line 715 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 715 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy53 = CONFIG_COND_NOMATCH;
 }
@@ -1565,12 +1565,12 @@ static void yy_reduce(
   yy_destructor(24,&yymsp[0].minor);
         break;
       case 41:
-#line 719 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 719 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   yygotominor.yy29 = NULL;
   if (ctx->ok) {
     if (yymsp[0].minor.yy91->type == TYPE_STRING) {
-      yygotominor.yy29 = buffer_init_buffer(&((data_string*)yymsp[0].minor.yy91)->value);
+      buffer_copy_buffer((yygotominor.yy29 = buffer_init()), &((data_string*)yymsp[0].minor.yy91)->value);
     } else if (yymsp[0].minor.yy91->type == TYPE_INTEGER) {
       yygotominor.yy29 = buffer_init();
       buffer_append_int(yygotominor.yy29, ((data_integer *)yymsp[0].minor.yy91)->value);
@@ -1585,7 +1585,7 @@ static void yy_reduce(
 #line 1585 "./configparser.c"
         break;
       case 42:
-#line 736 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 736 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_file(ctx->srv, ctx, yymsp[0].minor.yy29->ptr)) {
@@ -1599,7 +1599,7 @@ static void yy_reduce(
   yy_destructor(25,&yymsp[-1].minor);
         break;
       case 43:
-#line 746 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 746 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 {
   if (ctx->ok) {
     if (0 != config_parse_cmd(ctx->srv, ctx, yymsp[0].minor.yy29->ptr)) {
@@ -1639,7 +1639,7 @@ static void yy_parse_failed(
   while( yypParser->yyidx>=0 ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will be executed whenever the
   ** parser fails */
-#line 289 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.63-1.x86_64/src/lighttpd-1.4.63/src/configparser.y"
+#line 289 "/home/gps/src/gstrauss/cygport/cygport-lighttpd/lighttpd-1.4.64-6.i686/src/lighttpd-1.4.64/src/configparser.y"
 
   ctx->ok = 0;
 
